##  ServiceNow Is the Source
Consider an example where ServiceNow is the source system and SAP LeanIX is the target system. In ServiceNow, data representing software item names is stored in three fields: manufacturer, name, and edition. The matching rule manufacturer + name + edition = displayName enables the integration to identify and match items between the systems without creating duplicates.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio8ca5670a3a1644ebb490f2e2789c45b3_LowRes.png)
Example Matching Rule when ServiceNow Is the Source System
